@@ -3,10 +3,11 @@ package JSON::Meth;
 use strict;
 use warnings;
 
-our $VERSION = '1.001002'; # VERSION
+our $VERSION = '1.001003'; # VERSION
 
 use JSON::MaybeXS;
 use Carp;
+use Scalar::Util qw/blessed/;
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw($j);
@@ -19,21 +20,31 @@ use overload q{""}  => sub { $data },
 
 our $j = bless sub {
     my $in = shift;
-    return $data = decode_json $in
-        unless ref $in;
 
-    return $data = encode_json $in
+    my $json = JSON::MaybeXS->new(
+        convert_blessed => 1,
+        allow_blessed   => 1,
+    );
+
+    # plain data or object at root; just encode it
+    return $data = $json->decode($in)
+        if not ref $in
+            or ( blessed $in and blessed $in ne 'JSON::Meth' );
+
+    return $data = $json->encode($in)
         unless ref $in eq 'JSON::Meth';
 
+    # if we got up to here, then we're dealing with a $j->$j call
+
     defined $data
     or croak 'You tried to call $j->$j, but $j does not have any data '
         . ' stored. You need at least one encode/decode call prior to '
         . ' this, for $j->$j to work.';
 
-    return $data = decode_json $data
+    return $data = $json->decode($data)
         unless ref $data;
 
-    return $data = encode_json $data;
+    return $data = $json->encode($data);
 }, 'JSON::Meth';
 
 q{
@@ -45,7 +56,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords Znet Zoffix JSON  postfix
+=for stopwords Znet Zoffix JSON  postfix  ing
 
 =head1 NAME
 
@@ -55,6 +66,8 @@ JSON::Meth - no nonsense JSON encoding/decoding as method calls on data
 
 =for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-code.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
 
+=for test_synopsis use feature 'say';
+
     use JSON::Meth;
 
     # encode JSON:
@@ -75,10 +88,10 @@ JSON::Meth - no nonsense JSON encoding/decoding as method calls on data
     say for @$j;
 
     # go nuts! (outputs JSON string '["bar",{"ber":"beer"}]')
-    say '{"foo":["bar",{"ber":"beer"}]}'->$j->{foo}->$j
+    say '{"foo":["bar",{"ber":"beer"}]}'->$j->{foo}->$j;
 
     # event this works!! Meth? Not even once!
-    say '["woo","hoo!"]'->$j->$j->$j->$j
+    say '["woo","hoo!"]'->$j->$j->$j->$j;
 
 =for html  </div></div>
 
@@ -97,9 +110,9 @@ C<B<Meth>od>, which is the distinctive feature of this module.
 
 The module exports a single variable C<$j>. To encode/decode JSON,
 simply make a method call on your data, with C<$j> as
-the name of the method (see SYNOPSIS).
+the name of the method (see SYNOPSIS and THE MAGIC sections).
 
-=head2 THE MAGIC
+=head1 THE MAGIC
 
 The result of the last decode/encode operation is stored internally
 by the module and you can access that data by using C<$j> variable
@@ -118,6 +131,31 @@ If you're not a fan of postfix decoding, just use C<$j> as a prefix call:
 
 =for html <div style="background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/hr.png);height: 18px;"></div>
 
+=head1 CAVEATS
+
+The way this module deals with encoding objects is thusly:
+
+=over 4
+
+=item * if you're calling C<< ->$j >> on an object, it needs to
+implement stringification L<overload>ing and what it stringifies to
+will be decoded.
+
+=item * if you have an object somewhere inside a data structure you're
+encoding: if
+it implements C<TO_JSON> method, that method will be called, and the data
+returned used as json string to replace the object; if it doesn't
+implement such a method, it will be replaced with C<null>
+
+=back
+
+=head1 SEE ALSO
+
+For more full-featured encoders, see L<JSON::MaybeXS>,
+L<Mojo::JSON>, or L<Mojo::JSON::MaybeXS>.
+
+=for html <div style="background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/hr.png);height: 18px;"></div>
+
 =head1 REPOSITORY
 
 =for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-github.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
